OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Negadu (permissu eredadu)",
    "Allowed (Inherited permission)" : "Cunsentidu (permissu eredadu)",
    "Denied" : "Negadu",
    "Allowed" : "Cunsentidu",
    "Inherit permission" : "Ereda permissu",
    "Deny" : "Nega",
    "Allow" : "Permite",
    "Group" : "Grupu",
    "Read" : "Leghe",
    "Write" : "Iscrie",
    "Create" : "Crea",
    "Delete" : "Cantzella",
    "Share" : "Cumpartzidura",
    "You" : "Tue",
    "Remove access rule" : "Boga·nche règula de intrada",
    "Select a user or group" : "Seletziona un'utente o grupu",
    "Add group" : "Agiunghe grupu",
    "Default" : "Predefinidu",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "A beru boles cantzellare \"{folderName}\" e totu is archìvios in intro? Custa operatzione non si podet annullare ",
    "Delete \"{folderName}\"?" : "Boles cantzellare \"{folderName}\"?",
    "Folder name" : "Nùmene de sa cartella",
    "Quota" : "Cuota",
    "Advanced Permissions" : "Permissos avantzados",
    "Previous" : "Pretzedente",
    "Next" : "Imbeniente",
    "User" : "Utente",
    "Unknown" : "Disconnotu",
    "None" : "Perunu",
    "{size} used" : "{size} impreadu",
    "Unset" : "Non cunfiguradu"
},
"nplurals=2; plural=(n != 1);");
